import math
import matplotlib.pyplot as plt

class matrix_algebra:
    ''' basic matrix algebra such as addition, subtraction, multiplication, matrix inversion, etc. 
    
    Attributes:
    
    
    Actions:
    
    '''
    
    def __init__(self):
        
    
    
    def addition(self, other):
        if
    
